list_signals
============

:synopsis: Lists all signals defined in the project grouped by model and
           signal type


Example Usage
-------------

With *django-extensions* installed you can review all defined handlers using
*list_signals* command::

  # As above but non-interactive
  $ ./manage.py list_signals
